@@ -187,10 +187,11 @@ class LoadMaster(HttpClient):
         """Enable LoadMaster API"""
         # Can't use the HttpClient methods for this as the
         # endpoint is different when attempting to enable the API.
-        url = ("https://{user}:{pw}@{ip}"
+        url = ("https://{user}:{pw}@{ip}:{port}"
                "/progs/doconfig/enableapi/set/yes").format(user=self.username,
                                                            pw=self.password,
-                                                           ip=self.ip_address)
+                                                           ip=self.ip_address,
+                                                           port=self.port)
         try:
             requests.get(url, verify=False, timeout=1)
             return True
