@@ -83,3 +83,10 @@ class InvalidOperationException(KempTechApiException):
             cmd_name)
         super(InvalidOperationException, self).__init__(msg,
                                                         is_xml_msg=False)
+
+
+class ConnectionTimeoutException(KempTechApiException):
+    def __init__(self, lm):
+        msg = "Connection timed out to '{}'.".format(lm)
+        super(ConnectionTimeoutException, self).__init__(msg,
+                                                        is_xml_msg=False)
